Changes — Renku 0.15.2.dev42-g8ea0d1bb-dirty documentation

# Changes

## ` <https://github.com/SwissDataScienceCenter/renku-python/compare/v0.15.0…v0.15.1>`__ (2021-05-20)

### Bug Fixes

- core: remove locking from core read operations (#2099) (4407808)

- service: fix service project creation (#2092) (48d518f)

## ` <https://github.com/SwissDataScienceCenter/renku-python/compare/v0.14.2…v0.15.0>`__ (2021-05-17)

### Bug Fixes

- core: Fix annotations serialization in ProvenanceGraph (#1992) (eb3a7ba), closes #1952

- core: no failure when processing git history for deleted files (#2047) (d85facd)

- cli: fix path matching in renku log dot output (#2070) (4a4342b)

### Features

- cli: improve feedback around files being overwritten by renku init and add –initial-branch flag (#1997) (50bb67b)

- cli: add JSON output format to ‘renku dataset ls’ and ‘renku dataset ls-files’ (#2084) (514f13b)

- cli: add OLOS export and improve import/export provider logic (#1857) (779c481)

- cli: detect filename from content-disposition header when downloading (#2020) (c79ea14)

- core: add default value to all Run parameters (#2057) (3a0321d)

- core: adds node-js detection for rerun/update (#2002) (8b9e801)

- core: add renku login command to authenticate with a renku deployment (#1864) (7f3039f)

- dataset: add support to dataset update for detecting changes to local files (#2049) (71befe0)

- service: pass gitlab token to core-service (#2062) (63c2675)

- workflow: add naming metadata for command parameters (#2071) (b1e7a9b)

- workflow: add workflow naming metadata (#2033) (5612199)

- service: add delayed write operations, ie. porcelain and better cache management (#1957) (a05b615)

## ` <https://github.com/SwissDataScienceCenter/renku-python/compare/v0.14.1…v0.14.2>`__ (2021-04-16)

### Highlights

- Ability to update local project from its template and to update the Dockerfile to install the current version of renku-python using renku migrate.

- Support for Unicode paths in renku run (including emojis).

### Bug Fixes

- cli: fix renku rerun/update with unicode input/output paths (#1963) (9859b62)

- service: fix project_clone with git ref specified (#2008) (c072286)

### Features

- cli: support template and docker migration (#2019) (ed87770)

- dataset: support moving files between datasets with renku mv (#1993) (a715b70)

## 0.14.1 (2021-03-24)

### Bug Fixes

- core: Add error handling if push of temporary branch fails (#1979) (f8d7285)

- core: fix handling of ‘@’ in filenames (#1982) (41316b4)

- core: fix template update if same filename was added locally (#1974) (5b47ddc)

- core: fixes save and push to correctly handle merge conflicts (#1925) (fdac171)

- service: sync service cache with remote before operations to prevent cache getting out of sync (#1972) (34ec5d6)

### Features

- dataset: dataset import enhancements (#1970) (b3df7b8)

- service: renku service up/down/ps/restart/logs commands (#1899) (d9e49ae)

- service: add support for storing remote dataset images in the repo (#1878) (3862c2e)

## 0.14.0 (2021-03-05)

### Bug Fixes

- core: call git commands for batches of files to prevent hitting argument length limits (#1893) (deaf055)

- dataset: change renku dataset import to move temporary files and become more resilient to errors (#1894) (279407e)

- service correctly address HTTP server errors (#1872) (2fd5052)

- service correctly handle ref on project.clone (#1888) (7f30404)

- service use project_id as part of project filesystem path (#1754) (391a14a)

### Features

- cli: add renku storage migrate command to migrate git files to lfs (#1869) (bed1358)

- cli: add service component management commands (#1867) (928baf9)

- core: exclude renku metadata from being added to git lfs (#1898) (8046edb)

- core: add oauth authentication for KG access (#1881) (a568d31)

- dataset: improve naming for imported datasets (#1900) (9beb654)

- service: add build graph endpoint (#1571) (a7bfe3d)

- service: add renku config endpoints (#1834) (c09ca6b)

- service: add helm 3 values schema to chart (#1835) (57f6aee)

- service add root redirect to swagger docs (#1871) (1abd4f6)

- service: add support for adding images to datasets (#1850) (c3caafd)

## 0.13.0 (2021-01-29)

### Bug Fixes

- core: fix renku save with deleted files (#1849) (93348f9)

- core: migration error when multiple outputs bind to the same input (#1832) (bb19b47)

- core: output git lfs error messages when there is an error (#1838) (e2b5421)

- service: reset cache after failed push (#1836) (f41df17)

### Features

- cli: add dataset show command (#1798) (31e87f7)

- core: cache for workflow migrations (#1853) (f240d95)

- service: gzip decompression support (#1784) (59db473)

- service: use jwt sub claim as user-id (#1793) (06f815a)

## ` <https://github.com/SwissDataScienceCenter/renku-python/compare/v0.12.2…v0.12.3>`__ (2021-01-05)

### Bug Fixes

- core: fix gitlab ID parsing when GITLAB_BASE_URL is set without port (#1823) (4f94165)

- service: add datasets.remove to swagger docs (#1778) (631e6f5)

- service: correctly handle cloning of project with no commits (#1790) (440b238)

## ` <https://github.com/SwissDataScienceCenter/renku-python/compare/v0.12.1…v0.12.2>`__ (2020-12-02)

### Bug Fixes

- core: correctly generate project id for gitlab (sub)groups (#1746) (3fc29ad)

- core: fixes renku save to work with already staged changes (#1739) (1a8b7ad)

- core: adds pre-commit hook message for unsupported projects (#1730) (7f1731d)

- service: removes chdir calls in service (#1767) (4da22cb)

### Features

- api: adds user-api parameters support (#1723) (6ee2862)

- cli: adds migrationscheck command (#1761) (b33ed35)

- cli: automatically track files in git-lfs if necessary (#1775) (866163a)

- cli: better error messages for renku clone (#1738) (78bb2ad)

- core: shorten commit messages to 100 characters for readability (#1749) (af50947)

- service: move user identification to jwt (#1520) (d45c4c3)

## ` <https://github.com/SwissDataScienceCenter/renku-python/compare/v0.12.0…v0.12.1>`__ (2020-11-16)

### Bug Fixes

- core: re-raise renku handled exception on network failure (#1623) (4856a05)

- dataset: no commit if nothing is edited (#1706) (a68edf6)

- service: correctly determine resource age (#1695) (40153f0)

- service: correctly set project_name slug on project create (#1691) (234e1b3)

- service: set template version and metadata correctly (#1708) (ed98be3)

### Features

- renku API (#1665) (949a4aa)

## ` <https://github.com/SwissDataScienceCenter/renku-python/compare/v0.11.6…v0.12.0>`__ (2020-11-03)

### Bug Fixes

- core: fix bug where remote_cache caused project ids to leak (#1618) (3ef04fb)

- core: fix graph building for nodes with same subpath (#1625) (7cae9be)

- core: fix importing a dataset referenced from non-existent projects (#1574) (92b8bf8)

- core: fix old dataset migration and activity dataset outputs (#1603) (a5339e2)

- core: fix project migration getting overwritten with old metadata (#1581) (c5a5960)

- core: fix update creating a commit when showing help (#1627) (529e582)

- core: fixes git encoding of paths with unicode characters (#1538) (053dac9)

- core: make Run migration ids unique by relative path instead of absolute (#1573) (cf96310)

- dataset: broken directory hierarchy after renku dataset imports (#1576) (9dcffce)

- dataset: deserialization error (#1675) (420653f)

- dataset: error when adding same file multiple times (#1639) (05bfde7)

- dataset: explicit failure when cannot pull LFS objects (#1590) (3b05816)

- dataset: invalid generated name in migration (#1593) (89b2e43)

- dataset: remove blank nodes (#1602) (478f08c)

- dataset: set isBasedOn for renku datasets (#1617) (3aee6b8)

- dataset: update local files metadata when overwriting (#1582) (59eaf25)

- dataset: various migration issues (#1620) (f24c2e4)

- service: correctely set job timeout (#1677) (25f0eb6)

- service: dataset rm endpoint supports new core API (#1622) (e71916e)

- service: push to protected branches (#1614) (34c7f92)

- service: raise exception on uninitialized projects (#1624) (a2025c3)

### Features

- cli: add click plugin support (#1604) (47b007f)

- cli: adds consistent behaviour for cli commands (#1523) (20b7248)

- cli: show lfs status of dataset files (#1575) (a1c3e2a)

- cli: verbose output for renku show (#1524) (dae968c)

- core: Adds renku dataset update for Zenodo and Dataverse (#1331) (e38c51f)

- dataset: list dataset description (#1588) (7e13857)

- service: adds template and dockerfile migration to migration endpoint (#1509) (ea01795)

- service: adds version endpoint (#1548) (6193df6)

## 0.11.6 (2020-10-16)

### Bug Fixes

- core: fix bug where remote_cache caused project ids to leak (#1618) (3ef04fb)

- dataset: fix a bug where datasets imported from renku project won’t update (#1615) (309eb2f)

- service: fixes pushing to protected branches (#1614) (34c7f92)

## 0.11.5 (2020-10-13)

### Bug Fixes

- core: fix importing a dataset referenced from non-existent projects (#1574) (4bb13ef)

- core: fixes git encoding of paths with unicode characters (#1538) (9790707)

- dataset: fix broken directory hierarchy after renku dataset imports (#1576) (41e3e72)

- dataset: abort importing a dataset when cannot pull LFS objects (#1590) (9877a98)

- dataset: fix invalid dataset name after migration (#1593) (c7ec249)

- dataset: update dataset files metadata when adding and overwriting local files (#1582) (0a23e82)

## 0.11.4 (2020-10-05)

### Bug Fixes

- core: fix project migration getting overwritten with old metadata (#1580) (dcc1541)

## 0.11.3 (2020-09-29)

### Bug Fixes

- core: make Run migration ids unique by relative path instead of absolute (686b9f9)

## 0.11.2 (2020-09-24)

### Bug Fixes

- cli: fixes libxslt dependency in docker image (#1534) (491bae7)

- core: fixes ‘doi:…’ import (#1536) (f653c79)

- core: fixes duplicate ‘renku:Run’ ids on repeat execution of migrations (#1532) (4ce6f3c)

### Features

- cli: show existing paths when initializing non-empty dir (#1535) (07c559f)

- core: follow URL redirections for dataset files (#1516) (5a37b3c)

- dataset: flattened JSON-LD metadata (#1518) (458ddb9)

- service: add additional template parameters (#1469) (6372a32)

- service: adds additional fields to datasets listings (#1508) (f8a395f)

- service: adds project details and renku operation on jobs endpoint (#1492) (6b3fafd)

- service: execute read operations via git remote (#1488) (84a0eb3)

- workflow: avoid unnecessary parent runs (#1476) (b908ffd)

## 0.11.1 (2020-08-18)

### Bug Fixes

- fixes shacl for DatasetFile when used inside a qualifiedGeneration (#1477) (99dd4a4)

## 0.11.0 (2020-08-14)

### Bug Fixes

- cli: disable version check in githook calls (#1300) (5132db3)

- core: fix paths in migration of workflows (#1371) (8c3d34b)

- core: Fixes SoftwareAgent person context (#1323) (a207a7f)

- core: Only update project metadata if any migrations were executed (#1308) (1056a03)

- service: adds more custom logging and imp. except handling (#1435) (6c3adb5)

- service: fixes handlers for internal loggers (#1433) (a312f7c)

- service: move project_id to query string on migrations check (#1367) (0f89726)

- tests: integration tests (#1351) (3974a39)

### Features

- cli: Adds renku save command (#1273) (4ddc1c2)

- cli: prompt for missing variables (1e1d408), closes #1126

- cli: Show detailed commands for renku log output (#1345) (19fb819)

- core: Calamus integration (#1281) (bda538f)

- core: configurable data dir (#1347) (e388773)

- core: disabling of inputs/outputs auto-detection (#1406) (3245ca0)

- core: migration check in core (#1320) (4bc52f4)

- core: Move workflow serialisation over to calamus (#1386) (f0fbc49)

- core: save and load workflow as jsonld (#1185) (d403289)

- core: separate models for migrations (#1431) (127d606)

- dataset: source and url for DatasetFile (#1451) (b4fa5db)

- service: added endpoints to execute all migrations on a project (#1322) (aca8cc2)

- service: adds endpoint for explicit migrations check (#1326) (146b1a7)

- service: adds source and destination versions to migrations check (#1372) (ea76b48)

- decode base64 headers (#1407) (9901cc3)

- service: adds endpoints for dataset remove (#1383) (289e4b9)

- service: adds endpoints for unlinking files from a dataset (#1314) (1b78b16)

- service: async migrations execution (#1344) (ff66953)

- service: create new projects from templates (#1287) (552f85c), closes #862

## 0.10.5 (2020-07-16)

### Bug Fixes

- core: Pin dependencies to prevent downstream dependency updates from breaking renku. Fix pyshacl dependency. (#785) (30beedd)

- core: Fixes SoftwareAgent person context. (#1323) (fa62f58)

## 0.10.4 (2020-05-18)

### Bug Fixes

- dataset: update default behaviour and messaging on dataset unlink (#1275) (98d6728)

- dataset: correct url in different domain (#1211) (49e8b8b)

### Features

- cli: Adds warning messages for LFS, fix output redirection (#1199) (31969f5)

- core: Adds lfs file size limit and lfs ignore file (#1210) (1f3c81c)

- core: Adds renku storage clean command (#1235) (7029400)

- core: git hook to avoid committing large files (#1238) (e8f1a8b)

- core: renku doctor check for lfs migrate info (#1234) (480da06)

- dataset: fail early when external storage not installed (#1239) (e6ea6da)

- core: project clone API support for revision checkout (#1208) (74116e9)

- service: protected branches support (#1222) (8405ce5)

- dataset: doi variations for import (#1216) (0f329dd)

- dataset: keywords in metadata (#1209) (f98a800)

- dataset: no failure when adding ignored files (#1213) (b1e275f)

- service: read template manifest (#1254) (7eac85b)

## 0.10.3 (2020-04-22)

### Bug Fixes

- dataset: avoid recursive addition of data directory (#1163) (79e3b03)

- dataset: commit after unlinking files (#1120) (97e8754)

- dataset: Dataverse export (#1028) (737cecf)

### Features

- core: CLI warning when in non-root directory (#1162) (115e462)

- dataset: migrate submodule-based datasets (#1092) (dba20c4)

- dataset: no failure when adding existing files (#1177) (a68dcb7)

- dataset: remove –link flag (#1164) (969d4f8)

- dataset: show file size in ls-files (#1123) (0951930)

- datasets: specify title on dataset creation (#1204) (fb70ac5)

- init: read and display template variables (#1134) (0f86dc5), closes #1126

- service: add remote files to dataset (#1139) (f6bebfe)

## 0.10.1 (2020-03-31)

### Bug Fixes

- core: directory input regression (#1155) (b17c843)

- dataset: correct url when importing with DOI (#1156) (025b735)

### Features

- renku init options refactor (#1127) (78b208b)

- datasets: add files from dropbox (#1135) (bf5f2db)

## 0.10.0 (2020-03-25)

This release brings about several important Dataset features:

- importing renku datasets (#838)

- working with data external to the repository (#974)

- editing dataset metadata (#1111)

Please see the Dataset documentation for details.

Additional features were implemented for the backend service to facilitate a smoother user experience for dataset file manipulation.

IMPORTANT: starting with this version, a new metadata migration mechanism is in place (#1003). Renku commands will insist on migrating a project immediately if the metadata is found to be outdated.

### Bug Fixes

- cli: consistenly show correct contexts (#1096) (b333f0f)

- dataset: –no-external-storage flag not working (#1130) (c183e97)

- dataset: commit only updated dataset files (#1116) (d9739df)

- datasets: fixed importing large amount of small files (#1119) (8d61473)

- datasets: raises correct error message on import of protected dataset (#1112) (e579904)

### Features

- core: new migration mechanism (#1003) (1cc33d4)

- dataset: adding external data without copying (#974) (6a17512)

- dataset: bypass import confirmation (#1124) (947210a)

- dataset: import renku datasets (#838) (6aa3651)

- dataset: metadata edit (#1111) (66cfbbc)

- dataset: wildcard support when adding data from git (#1128) (baa1c9f)

## 0.9.1 (2020-02-24)

### Bug Fixes

- added test utility functions and cleanup (#1014) (f41100d)

- cache instance cleanup (#1051) (12f5446)

- enable dataset cmd in sub directories (#1012) (e3191e1)

- fields with default need to come last (#1046) (649b159)

- fixes renku show sibling handling with no paths (#1026) (8df678f)

- flush old keys for user projects and files (#1002) (7438c73)

- generate https IDs for entities instead of file:// (#1009) (87f7750)

- handle errors correctly (#1040) (950eeac)

- improved list datasets and files (#1034) (fd96d68)

- pin idna to 2.8 (#1020) (19ea7af)

- resync repo after import action (#1052) (b38341b)

- standardize test assertions (#1016) (16e8e63)

- temporarily disable integration tests (#1036) (8c8fd7a)

- updated readme to include local testing (#1000) (351a650)

- run tests via pipenv run commands (#999) (d8095e3)

### Features

- svc: adds job details endpoint (#1050) (9c58a08)

- svc: added list user jobs endpoint (#1001) (f3c200c)

- svc: dataset import via service (#1023) (d6c670a)

## 0.9.0 (2020-02-07)

### Bug Fixes

- adds git user check before running renku init (#892) (2e52dff)

- adds sorting to file listing (#960) (bcf6bcd)

- avoid empty commits when adding files (#842) (8533a7a)

- Fixes dataset naming (#898) (418deb3)

- Deletes temporary branch after renku init –force (#887) (eac0463)

- enforces label on SoftwareAgent (#869) (71badda)

- Fixes JSON-LD translation and related issues (#846) (65e5469)

- Fixes renku run error message handling (#961) (81d31ff)

- Fixes renku update workflow failure handling and renku status error handling (#888) (3879124)

- Fixes sameAs property to follow schema.org spec (#944) (291380e)

- handle missing renku directory (#989) (f938be9)

- resolves symlinks when pulling LFS (#981) (68bd8f5)

- serializes all zenodo metadata (#941) (787978a)

- Fixes various bugs in dataset import (#882) (be28bf5)

### Features

- add project initialization from template (#809) (4405744)

- added renku service with cache and datasets (#788) (7a7068d), closes #767 #846

- Adds protection for renku relevant paths in dataset add (#939) (a3c02e8)

- Adds prov:Invalidated output to renku log (008ab20)

- better UX when adding to a dataset (#911) (c6ac967)

- check for required git hooks (#854) (54ba91d)

- Dataverse export (#909) (7e9e647)

- improve dataset command output (#927) (c7639d3)

- metadata on dataset creation (#850) (b357ee7)

- Plugin support for renku-run (#883) (7dbda83)

- python 3.8 compatibility (#861) (4aaac8d)

- SHACL Validation (#767) (255a01d)

- update bug_report template to be more renku-relevant (#988) (e00ded7)

## 0.8.0 (2019-11-21)

### Bug Fixes

- addressed CI problems with git submodules (#783) (0d3eeb7)

- adds simple check on empty filename (#786) (8cd061b)

- ensure all Person instances have valid ids (4f80efc), closes #812

- Fixes jsonld issue when importing from dataverse (#759) (ffe36c6)

- fixes nested type scoped handling if a class only has a single class (#804) (16d03b6)

- ignore deleted paths in generated entities (86fedaf), closes #806

- integration tests (#831) (a4ad7f9)

- make Creator a subclass of Person (ac9bac3), closes #793

- Redesign scoped context in jsonld (#750) (2b1948d)

### Features

- avoid creation of nested datasets (#796) (6084c87)

- do not create dataset implicitly (#779) (84e59d0)

- local git repo not treated as remote (8cc2834)

- renku clone command (#828) (4b3b615)

## 0.7.0 (2019-10-15)

### Bug Fixes

- use UI-resolved project path as project ID (#701) (dfcc9e6)

## 0.6.1 (2019-10-10)

### Bug Fixes

- add .renku/tmp to default .gitignore (#728) (6212148)

- dataset import causes renku exception due to duplicate LocalClient (#724) (89411b0)

- delete new dataset ref if file add fails (#729) (2dea711)

- fixes bug with deleted files not getting committed (#741) (5de4b6f)

- force current project for entities (#707) (538ef07)

- integration tests for #681 (#747) (b08435d)

- use commit author for project creator (#715) (1a40ebe), closes #713

- zenodo dataset import error (f1d623a)

### Features

- adds basic QA checklist (#698) (c97e9bd)

- dataset tagging (#693) (797161f)

- include creator in project metadata (#687) ([9c7753e](https://git

## 0.6.0 (2019-09-18)

### Bug Fixes

- adds _label and commit data to imported dataset files, single commit for imports (#651) (75ce369)

- always add commit to dataset if possible (#648) (7659bc8), closes #646

- cleanup needed for integration tests on py35 (#653) (fdd7215)

- fixed serialization of datetime to iso format (#629) (693d59d)

- fixes broken integration test (#649) (04eba66)

- hide image, pull, runner, show, workon and deactivate commands (#672) (a3e9998)

- integration tests fixed (#685) (f0ea8f0)

- migration of old datasets (#639) (4d4d7d2)

- migration timezones (#683) (58c2de4)

- Removes unneccesary call to git lfs with no paths (#658) (e32d48b)

- renku home directory overwrite in tests (#657) (90e1c48)

- upload metadata before actual files (#652) (95ed468)

- use latest_html for version check (#647) (c6b0309), closes #641

- user-related metadata (#655) (44183e6)

- zenodo export failing with relative paths (d40967c)

### Features

- dataverse import (#626) (9f0f9a1)

- enable all datasets command to operate on dirty repository (#607) (74e328b)

- explicit input output specification (#598) (ce8ba67)

- export filename as schema:name (#643) (aed54bf), closes #640

- support for indirect inputs and outputs (#650) (e960a98)

## 0.5.2 (2019-07-26)

### Bug Fixes

- safe_path check always operates on str (#603) (7c1c34e)

### Features

- add SoftwareAgent to Activity (#590) (a60c20c), closes #508

## 0.5.1 (2019-07-12)

### Bug Fixes

- ensure external storage is handled correctly (#592) (7938ac4)

- only check local repo for lfs filter (#575) (a64dc79)

- cli: allow renku run with many inputs (f60783e), closes #552

- added check for overwriting datasets (#541) (8c697fb)

- escape whitespaces in notebook name (#584) (0542fcc)

- modify json-ld for datasets (#534) (ab6a719), closes #525 #526

- refactored tests and docs to align with updated pydoctstyle (#586) (6f981c8)

- cli: add check of missing references (9a373da)

- cli: fail when removing non existing dataset (dd728db)

- status: fix renku status output when not in root folder (#564) (873270d), closes #551

- added dependencies for SSL support (#565) (4fa0fed)

- datasets: strip query string from data filenames (450898b)

- fixed serialization of creators (#550) (6a9173c)

- updated docs (#539) (ff9a67c)

- cli: remove dataset aliases (6206e62)

- cwl: detect script as input parameter (e23b75a), closes #495

- deps: updated dependencies (691644d)

### Features

- add dataset metadata to the KG (#558) (fb443d7)

- datasets: export dataset to zenodo (#529) (fc6fd4f)

- added support for working on dirty repo (ae67be7)

- datasets: edit dataset metadata (#549) (db39083)

- integrate metadata from zenodo (#545) (4273d2a)

- config: added global config manager (#533) (938f820)

- datasets: import data from zenodo (#509) (52b2769)

## 0.5.0 (2019-03-28)

### Bug Fixes

- api: make methods lock free (1f63964), closes #486

- use safe_load for parsing yaml (5383d1e), closes #464

- datasets: link flag on dataset add (eae30f4)

### Features

- api: list datasets from a commit (04a9fe9)

- cli: add dataset rm command (a70c7ce)

- cli: add rm command (cf0f502)

- cli: configurable format of dataset output (d37abf3)

- dataset: add existing file from current repo (575686b), closes #99

- datasets: added ls-files command (ccc4f59)

- models: reference context for relative paths (5d1e8e7), closes #452

- add JSON-LD output format for datasets (c755d7b), closes #426

- generate Makefile with log –format Makefile (1e440ce)

## `v0.4.0`

(released 2019-03-05)

- Adds `renku mv` command which updates dataset metadata, `.gitattributes` and symlinks.

- Pulls LFS objects from submodules correctly.

- Adds listing of datasets.

- Adds reduced dot format for `renku log`.

- Adds `doctor` command to check missing files in datasets.

- Moves dataset metadata to `.renku/datasets` and adds `migrate datasets` command and uses UUID for metadata path.

- Gets git attrs for files to prevent duplicates in `.gitattributes`.

- Fixes `renku show outputs` for directories.

- Runs Git LFS checkout in a worktrees and lazily pulls necessary LFS files before running commands.

- Asks user before overriding an existing file using `renku init` or `renku runner template`.

- Fixes `renku init --force` in an empty dir.

- Renames `CommitMixin._location` to `_project`.

- Addresses issue with commits editing multiple CWL files.

- Exports merge commits for full lineage.

- Exports path and parent directories.

- Adds an automatic check for the latest version.

- Simplifies issue submission from traceback to GitHub or Sentry. Requires `SENTRY_DSN` variable to be set and sentry-sdk package to be installed before sending any data.

- Removes outputs before run.

- Allows update of directories.

- Improves readability of the status message.

- Checks ignored path when added to a dataset.

- Adds API method for finding ignored paths.

- Uses branches for `init --force`.

- Fixes CVE-2017-18342.

- Fixes regex for parsing Git remote URLs.

- Handles `--isolation` option using `git worktree`.

- Renames `client.git` to `client.repo`.

- Supports `python -m renku`.

- Allows ‘.’ and ‘-‘ in repo path.

## `v0.3.3`

(released 2018-12-07)

- Fixes generated Homebrew formula.

- Renames `renku pull path` to `renku storage pull` with deprecation warning.

## `v0.3.2`

(released 2018-11-29)

- Fixes display of workflows in `renku log`.

## `v0.3.1`

(released 2018-11-29)

- Fixes issues with parsing remote Git URLs.

## `v0.3.0`

(released 2018-11-26)

- Adds JSON-LD context to objects extracted from the Git repository (see `renku show context --list`).

- Uses PROV-O and WFPROV as provenance vocabularies and generates “stable” object identifiers (`@id`) for RDF and JSON-LD output formats.

- Refactors the log output to allow linking files and directories.

- Adds support for aliasing tools and workflows.

- Adds option to install shell completion (`renku --install-completion`).

- Fixes initialization of Git submodules.

- Uses relative submodule paths when appropriate.

- Simplifies external storage configuration.

## `v0.2.0`

(released 2018-09-25)

- Refactored version using Git and Common Workflow Language.

## `v0.1.0`

(released 2017-09-06)

- Initial public release as Renga.